AxmlError

Enum AxmlError 

#[non_exhaustive]
pub enum AxmlError { UnexpectedEof, InvalidMagic(u16), InvalidChunkType(u16), InvalidStringIndex(usize, usize), Utf8Error(FromUtf8Error), Utf16Error(DecodeUtf16Error), XmlError(String), SliceError(String), ProtoError(DecodeError), IoError(Error), }
Re-export the error type so downstream crates can name it. Error type for AXML and ARSC parsing and manipulation.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


UnexpectedEof

Unexpected end of input while reading a required field.



InvalidMagic(u16)

Invalid magic bytes for AXML or ARSC format.



InvalidChunkType(u16)

Invalid chunk type identifier.



InvalidStringIndex(usize, usize)

String index out of bounds (requested index, valid count).



Utf8Error(FromUtf8Error)

UTF-8 decoding error from the string pool.



Utf16Error(DecodeUtf16Error)

UTF-16 decoding error from the string pool.



XmlError(String)

XML parsing or generation error.



SliceError(String)

Slice bounds or format error.



ProtoError(DecodeError)

Protobuf message decoding error.



IoError(Error)

File I/O error.